macro_rules! init {
() => { ... };
}Expand description
Initialize the cufflink-fn runtime. Call this once at the top of your lib.rs.
Exports the alloc function that the platform needs to pass data into
your WASM module.
ⓘ
use cufflink_fn::prelude::*;
cufflink_fn::init!();